.. module:: enaml.widgets.time_selector

===========================
enaml.widgets.time_selector
===========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    TimeSelector


.. autoclass:: TimeSelector
